pub struct CheckpointResponse {
pub sequence_number: CheckpointSequenceNumber,
pub summary: Option<CheckpointSummary>,
pub signature: Option<ValidatorAggregatedSignature>,
pub contents: Option<CheckpointContents>,
pub executed_transactions: Vec<ExecutedTransaction>,
pub events: Vec<Event>,
}Expand description
Response for a checkpoint query.
Contains checkpoint summary, signature, contents, transactions, and events.
Fields are proto types that can be accessed directly or converted to SDK
types using their conversion methods (e.g.,
response.summary()?.summary()?, response.contents()?.contents()?).
Fields
sequence_number: CheckpointSequenceNumberThe checkpoint sequence number.
summary: Option<CheckpointSummary>Proto checkpoint summary. Use response.summary()?.summary() to convert
to SDK type.
signature: Option<ValidatorAggregatedSignature>Proto validator signature. Use response.signature()?.signature() to
convert to SDK type.
contents: Option<CheckpointContents>Proto checkpoint contents. Use response.contents()?.contents() to
convert to SDK type.
executed_transactions: Vec<ExecutedTransaction>Proto executed transactions. Use methods like tx.effects()?,
tx.transaction()?, etc.
events: Vec<Event>Proto events. Use event.try_into() or event.events() to convert to
SDK types.
Implementations
Sourceimpl CheckpointResponse
impl CheckpointResponse
Sourcepub fn sequence_number(&self) -> CheckpointSequenceNumber
pub fn sequence_number(&self) -> CheckpointSequenceNumber
Get the checkpoint sequence number.
Always available regardless of the read mask.
Sourcepub fn summary(&self) -> Result<&CheckpointSummary>
pub fn summary(&self) -> Result<&CheckpointSummary>
Get the checkpoint summary.
Returns the proto
CheckpointSummary
which provides:
Read mask: "checkpoint.summary" (see
CHECKPOINT_RESPONSE_SUMMARY)
Sourcepub fn signed_summary(&self) -> Result<SignedCheckpointSummary>
pub fn signed_summary(&self) -> Result<SignedCheckpointSummary>
Build a SignedCheckpointSummary
from the response.
Requires the checkpoint summary and signature to be present.
Read mask: see CHECKPOINT_RESPONSE_SIGNED_SUMMARY
Sourcepub fn signature(&self) -> Result<&ValidatorAggregatedSignature>
pub fn signature(&self) -> Result<&ValidatorAggregatedSignature>
Get the validator aggregated signature for the checkpoint.
Read mask: "checkpoint.signature" (see
CHECKPOINT_RESPONSE_SIGNATURE)
Sourcepub fn contents(&self) -> Result<&CheckpointContents>
pub fn contents(&self) -> Result<&CheckpointContents>
Get the checkpoint contents.
Returns the proto
CheckpointContents
which provides:
digest()— the contents digestcontents()— the deserialized SDKCheckpointContents
Read mask: "checkpoint.contents" (see
CHECKPOINT_RESPONSE_CONTENTS)
Sourcepub fn executed_transactions(&self) -> &Vec<ExecutedTransaction>
pub fn executed_transactions(&self) -> &Vec<ExecutedTransaction>
Get the executed transactions in this checkpoint.
Returns proto
ExecutedTransaction
values. Which sub-fields are populated depends on the read mask; use
paths like "transactions.effects" or "transactions.transaction".
Read mask: "transactions" for all sub-fields (see
CHECKPOINT_RESPONSE_EXECUTED_TRANSACTIONS)
Sourcepub fn events(&self) -> &Vec<Event>
pub fn events(&self) -> &Vec<Event>
Get the top-level events for this checkpoint.
Returns proto Event values.
Which sub-fields are populated depends on the read mask; use paths like
"events.bcs" or "events.event_type".
Read mask: "events" for all sub-fields (see
CHECKPOINT_RESPONSE_EVENTS)
Sourcepub fn checkpoint_data(&self) -> Result<CheckpointData>
pub fn checkpoint_data(&self) -> Result<CheckpointData>
Build a full
CheckpointData
from the response.
Requires the checkpoint summary, signature, contents, and all transaction data (transaction, signatures, effects, events, input_objects, output_objects) to be present in the response.
Read mask: see CHECKPOINT_RESPONSE_CHECKPOINT_DATA
Example
use iota_grpc_client::CHECKPOINT_RESPONSE_CHECKPOINT_DATA;
let client = Client::connect("http://localhost:9000").await?;
let cp = client
.get_checkpoint_latest(Some(CHECKPOINT_RESPONSE_CHECKPOINT_DATA), None, None)
.await?;
let data = cp.body().checkpoint_data()?;Trait Implementations
Sourceimpl Clone for CheckpointResponse
impl Clone for CheckpointResponse
Sourcefn clone(&self) -> CheckpointResponse
fn clone(&self) -> CheckpointResponse
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !Freeze for CheckpointResponse
impl RefUnwindSafe for CheckpointResponse
impl Send for CheckpointResponse
impl Sync for CheckpointResponse
impl Unpin for CheckpointResponse
impl UnwindSafe for CheckpointResponse